/* ============================================================= */
/* gdemo.c: graphics demo showing initialization of screen       */
/*                                                               */
/* to compile:                                                   */
/*                                                               */
/*         lsctcc gdemo.c -l t8graph                             */
/*                                                               */
/* (the -l option specifies the library to link with the program */
/*                                                               */
/* to run:                                                       */
/*                                                               */
/*         ld-one gdemo gcio                                     */
/*                                                               */
/* ============================================================= */

#include "graph.h"
#include <stdio.h>

int    GraphDriver;             /* The Graphics device driver           */
int    GraphMode;                 /* The Graphics mode value            */
int    MaxX, MaxY;              /* The maximum resolution of the screen */
int    ErrorCode;               /* Reports any graphics errors          */
char *lname[] = {"SOLID_LINE",
                                                                 "DOTTED_LINE",
                                                                 "CENTER_LINE",
                                                                 "DASHED_LINE",
                                                                 "USERBIT_LINE"
                                                                 };

void Initialize(void)
{
        char error[80];

        GraphDriver = DETECT;                                /* Request auto-detection */
        initgraph( &GraphDriver, &GraphMode, "" );      /* Use current directory */
        ErrorCode = graphresult();                        /* Read result of initialization */
        if( ErrorCode != grOk ) {                             /* Error occured during init */
                grapherrormsg(ErrorCode,error);
                printf(" Graphics System Error: %s\n", error );
    exit( 1 );
  }

        MaxX = getmaxx();
        MaxY = getmaxy();                                                                                                                           /* Read size of screen */
}

void colorboxes()
{
        int i;

        setcolor(WHITE);
        outtextxy(36,20,"Colors");
        for (i=0;i<=getmaxcolor();i++) {
                setfillstyle(SOLID_FILL,i);
                bar3d(40,40+i*20,80,54+i*20,0,0);
        }
}

void drawlines()
{

        int userpat=1;  /* binary "0000000000000001" */
        int style;
        char stylestr[40];

        outtextxy(255,20,"Lines");

        for (style=SOLID_LINE; style<=USERBIT_LINE; style++) {
                /* select the line style */
                setlinestyle(style,userpat,1);

                /* convert style into a string */
                strcpy(stylestr,lname[style]);

                /* output a message */
                setcolor(WHITE);
                outtextxy(150,40+style*40,stylestr);

                /* draw line */
                setcolor(LIGHTGREEN);
                line(260,44+style*40,400,44+style*40);
        }
        setlinestyle(SOLID_LINE,0,1);
}

void fill()
{
        int poly[] = {475,225,525,225,525,250,575,250,575,325,475,325,475,225};

        setcolor(WHITE);
        outtextxy(500,20,"Fills");

        setcolor(WHITE);
        setfillstyle(INTERLEAVE_FILL,MAGENTA);
        pieslice(525,125,45,360,60);

        setfillstyle(CLOSE_DOT_FILL,LIGHTBLUE);
        fillpoly(sizeof(poly)/(sizeof(int)*2),poly);
}

void viewport()
{
        setcolor(WHITE);
        outtextxy(221,260,"Clipped Viewport");
        rectangle(209,279,361,421);
        setviewport(210,280,360,420,1);
        setcolor(YELLOW);
        line(50,50,640,420);
        line(0,300,100,0);
        line(0,75,500,75);
        setviewport(0,0,MaxX,MaxY,1);
}

void main(void)
{
        Initialize();
        setcolor(CYAN);
        rectangle(0,0,MaxX,MaxY);
        colorboxes();
        drawlines();
        fill();
        viewport();
        setcolor(WHITE);
        outtextxy(232,470,"Press any key to exit.");
        getch();
        closegraph();
}
